PolicyMarker

Struct PolicyMarker 

pub struct PolicyMarker<P>(/* private fields */)
where
    P: AllocPolicy;
Zero-sized type (ZST) that brands a data structure with the allocator policy used to create it — zero runtime cost (PhantomData<P>).

Embed PolicyMarker<P> in consumer types to carry the policy as a compile-time proof without any runtime overhead.

Implementations

Source

impl<P> PolicyMarker<P>
where P: AllocPolicy,

pub const fn new() -> PolicyMarker<P>

Creates a new zero-cost marker.

pub const fn name() -> &'static str

Returns the compile-time policy name.

pub const fn fingerprint() -> u64

Returns the compile-time policy fingerprint.

pub const fn mitigation_flags() -> u32

Returns the compile-time mitigation flags bitmask.